import string
from fastapi import FastAPI, HTTPException
import uvicorn
import sqlite3
from fastapi.middleware.cors import CORSMiddleware
from pydantic import BaseModel
from typing import Union
import sys
from datetime import datetime

app = FastAPI()


origins = [
    "*",
]

app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)


con = sqlite3.connect('./fake_data.db')
cur = con.cursor()


class Personnel(BaseModel):
    nickname: str
    gender: int
    idCard: str
    company: str
    post: str
    role: str


@app.get("/")
async def root():
    return {"message": "Hello World"}


# 人员信息管理
@app.get('/personnels')
async def getPersonnelsList(pageNum: int = 1, pageSize: int = 10):
    try:
        res = cur.execute(
            "SELECT id, nickname, gender, idCard, company, post, role FROM personnel_information_management")
        tupleRes = res.fetchall()
        rows = []
        total = len(tupleRes)
        for item in tupleRes[(pageNum-1)*pageSize:(pageNum)*pageSize]:
            dataObj = {"id": item[0], "nickname": item[1],
                       "gender": item[2], "idCard": item[3], "company": item[4], "post": item[5], "role": item[6]}
            rows.append(dataObj)
        return {"msg": 'success', "rows": rows, "total": total, "pageNum": pageNum, "pageSize": pageSize}
    except:
        raise HTTPException(status_code=502, detail="error")


@app.post('/personnels')
async def insertPersonnel(personnel: Personnel):
    try:
        cur.execute("INSERT INTO personnel_information_management ( nickname, gender, idCard, company, post, role ) VALUES ( ?, ?, ?, ?, ?, ? )",
                    [personnel.nickname, personnel.gender, personnel.idCard, personnel.company, personnel.post, personnel.role])
        con.commit()
        return {"msg": 'success'}
    except:
        print("Unexpected error:", sys.exc_info()[0])
        raise HTTPException(status_code=502, detail="error")


@app.get('/personnels/{id}')
async def getPersonnelById(id):
    try:
        res = cur.execute(
            "SELECT * FROM personnel_information_management WHERE id=?", [id])
        item = res.fetchone()
        print(item)
        return {"msg": 'success', "data":  {"id": item[0], "nickname": item[1],
                                            "gender": item[2], "idCard": item[3], "company": item[4], "post": item[5], "role": item[6]}}
    except:
        print("Unexpected error:", sys.exc_info()[0])
        raise HTTPException(status_code=502, detail="error")


@app.put('/personnels/{id}')
async def updatePersonnel(id: int, personnel: Personnel):
    try:
        cur.execute(
            "UPDATE personnel_information_management SET nickname=?, gender=?, idCard=?, company=?, post=?, role=? WHERE id=?", ((personnel.nickname, personnel.gender, personnel.idCard, personnel.company, personnel.post, personnel.role, id)))
        return {"msg": "update data success"}
    except:
        raise HTTPException(status_code=502, detail="error")


@app.delete('/personnels/{id}')
async def removePersonnel(id):
    try:
        cur.execute(
            "DELETE FROM personnel_information_management WHERE id=?", [id])
        con.commit()
        return {"msg": "delete "+id+'success'}
    except:
        raise HTTPException(status_code=502, detail="error")


# 组织管理
class Organizational(BaseModel):
    name: str
    sort: int
    status: int

# 组织列表


@app.get('/organizational')
async def getOrganizationalList(pageNum: int = 1, pageSize: int = 10, name: str = "%", status: int = "%"):
    try:
        res = cur.execute(
            "SELECT id, name, sort, status, createTime FROM organizational_management WHERE name LIKE ? AND status LIKE ? ORDER BY sort ASC", ["%" if name == "%" else "%"+name+"%", status])
        tupleRes = res.fetchall()
        rows = []
        total = len(tupleRes)
        for item in tupleRes[(pageNum-1)*pageSize:(pageNum)*pageSize]:
            dataObj = {"id": item[0], "name": item[1],
                       "sort": item[2], "status": item[3], "createTime": item[4]}
            rows.append(dataObj)
        return {"msg": 'success', "rows": rows, "total": total, "pageNum": pageNum, "pageSize": pageSize}
    except:
        raise HTTPException(status_code=502, detail="error")

# 添加组织


@app.post('/organizational')
async def insertOrganizational(organizational: Organizational):
    try:
        cur.execute("INSERT INTO organizational_management ( name, sort, status, createTime ) VALUES ( ?, ?, ?, ? )",
                    [organizational.name, organizational.sort, organizational.status, datetime.now().strftime('%Y-%m-%d %X')])
        con.commit()
        return {"msg": 'success'}
    except:
        print("Unexpected error:", sys.exc_info()[0])
        raise HTTPException(status_code=502, detail="error")

# 根据id获取组织


@app.get('/organizational/{id}')
async def getOrganizationalById(id):
    try:
        res = cur.execute(
            "SELECT * FROM organizational_management WHERE id=?", [id])
        item = res.fetchone()
        print(item)
        return {"msg": 'success', "data":  {"id": item[0], "name": item[1],
                                            "sort": item[2], "status": item[3], "createTime": item[4]}}
    except:
        print("Unexpected error:", sys.exc_info()[0])
        raise HTTPException(status_code=502, detail="error")


@app.put('/organizational/{id}')
async def updateOrganizational(id: int, organizational: Organizational):
    try:
        cur.execute(
            "UPDATE organizational_management SET name=?, sort=?, status=? WHERE id=?", [organizational.name, organizational.sort, organizational.status, id])
        return {"msg": "update data success"}
    except:
        raise HTTPException(status_code=502, detail="error")


@app.delete('/organizational/{id}')
async def removeOrganizational(id):
    try:
        cur.execute(
            "DELETE FROM organizational_management WHERE id=?", [id])
        con.commit()
        return {"msg": "delete "+id+'success'}
    except:
        raise HTTPException(status_code=502, detail="error")


# ------------------------项目企业管理----------------------------
class ProjectCompany(BaseModel):
    name: str
    address: str
    legalPerson: str
    legalPersonPhone: int
    bank: int
    taxId: str
    contact: str
    contactPhone: int
    creditCode: str
    companyType: str
    region: str
    status: int
# 企业列表


@app.get('/project_company')
async def getProjectCompanyList(pageNum: int = 1, pageSize: int = 10, name: str = "%", creditCode: str = "%"):
    try:
        res = cur.execute(
            "SELECT id, name, address, legalPerson, legalPersonPhone, bank, taxId, contact, contactPhone, creditCode, companyType, region, status FROM project_company WHERE name LIKE ? AND creditCode LIKE ?", ["%" if name == "%" else "%"+name+"%", creditCode])
        tupleRes = res.fetchall()
        rows = []
        total = len(tupleRes)
        for item in tupleRes[(pageNum-1)*pageSize:(pageNum)*pageSize]:
            dataObj = {"id": item[0], "name": item[1], "address": item[2], "legalPerson": item[3], "legalPersonPhone": item[4], "bank": item[5],
                       "taxId": item[6], "contact": item[7], "contactPhone": item[8], "creditCode": item[9], "companyType": item[10], "region": item[11], "status": item[12]}
            rows.append(dataObj)
        return {"msg": 'success', "rows": rows, "total": total, "pageNum": pageNum, "pageSize": pageSize}
    except:
        print("Unexpected error:", sys.exc_info()[0])
        raise HTTPException(status_code=502, detail="error")


@app.post('/project_company')
async def insertProjectCompany(projectCompany: ProjectCompany):
    try:
        cur.execute("INSERT INTO project_company ( name, address, legalPerson, legalPersonPhone, bank, taxId, contact, contactPhone, creditCode, companyType, region, status ) VALUES ( ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )",
                    [projectCompany.name, projectCompany.address, projectCompany.legalPerson, projectCompany.legalPersonPhone, projectCompany.bank, projectCompany.taxId, projectCompany.contact, projectCompany.contactPhone, projectCompany.creditCode, projectCompany.companyType, projectCompany.region, projectCompany.status])
        con.commit()
        return {"msg": 'success'}
    except:
        print("Unexpected error:", sys.exc_info()[0])
        raise HTTPException(status_code=502, detail="error")


# 根据id获取iqye


@app.get('/project_company/{id}')
async def getProjectCompanyById(id):
    try:
        res = cur.execute(
            "SELECT * FROM project_company WHERE id=?", [id])
        item = res.fetchone()
        return {"msg": 'success', "data":  {"id": item[0], "name": item[1], "address": item[2], "legalPerson": item[3], "legalPersonPhone": item[4], "bank": item[5],
                                            "taxId": item[6], "contact": item[7], "contactPhone": item[8], "creditCode": item[9], "companyType": item[10], "region": item[11], "status": item[12]}}
    except:
        print("Unexpected error:", sys.exc_info()[0])
        raise HTTPException(status_code=502, detail="error")
# 删除企业


@app.delete('/project_company/{id}')
async def removeProjectCompany(id):
    try:
        cur.execute(
            "DELETE FROM project_company WHERE id=?", [id])
        con.commit()
        return {"msg": "delete "+id+'success'}
    except:
        raise HTTPException(status_code=502, detail="error")


def runApp():
    uvicorn.run('fake_data.main:app', host="127.0.0.1", port=8000, reload=True)
